'use strict';

module.exports = makeBroadcastManager;

/**
 * Returns a broadcast manager
 *
 * @param configRepository An object that provides a `get` method for getting config values with dot notation'`
 * @param eventsRepository
 * @param broadcastersRepository
 * @returns {{broadcast: (function(*=, *=, *=))}}
 */
function makeBroadcastManager(configRepository, eventsRepository, broadcastersRepository) {
    return {
        broadcast: function broadcast(event, payload) {
            var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

            var broadcastChannel = eventsRepository.broadcastConfig(event).broadcastOn;
            if (!broadcastChannel) {
                return;
            }

            var broadcastDriver = configRepository.get('broadcaster');
            if (broadcastDriver === null) {
                return;
            }

            var broadcastingConfig = configRepository.get(broadcastDriver);
            var broadcaster = broadcastersRepository.get(broadcastDriver, broadcastingConfig);
            if (typeof broadcastChannel === 'function') {
                broadcastChannel = broadcastChannel(payload);
            }
            broadcaster.broadcast(broadcastChannel, event, payload, options);
        }
    };
}